# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports = [
    ../common.nix
    ./hardware-configuration.nix
    ./users.nix
    ./services.nix
  ];

  boot = {
    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };

    supportedFilesystems = [ "zfs" ];

    tmpOnTmpfs = true;
  };

  services.zfs = {
    autoSnapshot.enable = true;
    autoScrub.enable = true;
  };

  networking = {
    hostName = "loutreos"; # Define your hostname.
    hostId = "7e66e347";
  };

  nixpkgs.overlays = [
    (import ../../overlays/riot-web.nix)
    (import ../../overlays/site-max.nix)
    (import ../../overlays/site-musique.nix)
    (import ../../overlays/dogetipbot-telegram.nix)
    (import ../../overlays/unstable_pkgs.nix)
  ];

  services.openssh = {
    enable = true;
    permitRootLogin = "no";
    passwordAuthentication = false;
  };

  networking.firewall = {
    allowedTCPPorts = [  ];
    allowedUDPPorts = [  ];
    enable = true;
  };

  security.sudo.wheelNeedsPassword = false;

  system.autoUpgrade.enable = true;
  systemd.services.nixos-upgrade.path = with pkgs; [ gzip gnutar xz.bin config.nix.package.out ];

  system.stateVersion = "18.03";
}
